==> functime-0.3.1-py3-none-any.whl: functime/ranges.py <==
from typing import Optional

import polars as pl

from functime.offsets import _strip_freq_alias


def make_future_ranges(
    time_col: str,
    cutoffs: pl.DataFrame,
    fh: int,
    freq: Optional[str] = None,
    time_unit: Optional[str] = None,
) -> pl.DataFrame:
    """Return pl.DataFrame with columns entity_col, time_col.
    DataFrame has shape (n_entities, 2) and dtypes (str, list[date]) or (str, list[datetime]).
    """
    entity_col = cutoffs.columns[0]
    if isinstance(freq, str):
        if freq.endswith("i"):
            future_ranges = cutoffs.select(
                [
                    pl.col(entity_col),
                    pl.arange(
                        pl.col("low") + 1,
                        pl.col("low") + fh + 1,
                        step=int(freq[:-1]),
                        eager=False,
                    ).alias(time_col),
                ]
            )
        else:
            time_unit = time_unit or "us"
            offset_n, offset_alias = _strip_freq_alias(freq)
            # Make date ranges
            future_ranges = cutoffs.select(
                [
                    pl.col(entity_col),
                    pl.date_range(
                        pl.col("low"),
                        pl.col("low")
                        .dt.offset_by(f"{fh * offset_n}{offset_alias}")
                        .alias("high"),
                        interval=freq,
                        closed="right",
                        time_unit=time_unit,
                        eager=False,
                    ).alias(time_col),
                ]
            )
    else:
        future_ranges = cutoffs.select(
            [
                pl.col(entity_col),
                pl.arange(
                    pl.ones(len(cutoffs), eager=False),
                    pl.ones(len(cutoffs), eager=False) + fh,
                    eager=False,
                ).alias(time_col),
            ]
        )
    return future_ranges

==> functime-0.3.3-py3-none-any.whl: functime/ranges.py <==
from typing import Optional

import polars as pl

from functime.offsets import _strip_freq_alias


def make_future_ranges(
    time_col: str,
    cutoffs: pl.DataFrame,
    fh: int,
    freq: Optional[str] = None,
    time_unit: Optional[str] = None,
) -> pl.DataFrame:
    """Return pl.DataFrame with columns entity_col, time_col.

    DataFrame has shape (n_entities, 2) and dtypes (str, list[date]), (str, list[datetime]), or (str, list[int]).
    """
    entity_col = cutoffs.columns[0]
    if isinstance(freq, str):
        if freq.endswith("i"):
            future_ranges = cutoffs.select(
                [
                    pl.col(entity_col),
                    pl.arange(
                        pl.col("low") + 1,
                        pl.col("low") + fh + 1,
                        step=int(freq[:-1]),
                        eager=False,
                    ).alias(time_col),
                ]
            )
        else:
            time_unit = time_unit or "us"
            offset_n, offset_alias = _strip_freq_alias(freq)
            # Make date ranges
            future_ranges = cutoffs.select(
                [
                    pl.col(entity_col),
                    pl.date_range(
                        pl.col("low"),
                        pl.col("low")
                        .dt.offset_by(f"{fh * offset_n}{offset_alias}")
                        .alias("high"),
                        interval=freq,
                        closed="right",
                        time_unit=time_unit,
                        eager=False,
                    ).alias(time_col),
                ]
            )
    else:
        future_ranges = cutoffs.select(
            [
                pl.col(entity_col),
                pl.arange(
                    pl.ones(len(cutoffs), eager=False),
                    pl.ones(len(cutoffs), eager=False) + fh,
                    eager=False,
                ).alias(time_col),
            ]
        )
    return future_ranges
